@@ -18,6 +18,9 @@ class Game:
     def draw( self ):
         ...
 
+    def exit( self ):
+        ...
+
 
 # --------
 # This is just some boilerplate that makes it easier to use a custom Game class
@@ -32,4 +35,7 @@ def vvs_update( dt ):
     _GAME.update( dt )
 
 def vvs_draw():
-    _GAME.draw()
\ No newline at end of file
+    _GAME.draw()
+
+def vvs_exit():
+    _GAME.exit()
\ No newline at end of file
